import { __assign, __decorate, __metadata, __param } from "tslib";
import { injectable, multiInject } from 'inversify';
import { DEPENDENCIES } from '../../../container/container.const';
import { pipeMappers } from '../../pipe-mappers';
/**
 * Hierarchical Empathy facet mapper.
 *
 * @public
 */
var EmpathyHierarchicalFacetMapper = /** @class */ (function () {
    function EmpathyHierarchicalFacetMapper(filterMappers) {
        this.mapFilter = pipeMappers.apply(void 0, filterMappers);
    }
    EmpathyHierarchicalFacetMapper.prototype.map = function (rawFacet, facet, context) {
        if (facet.modelName === 'HierarchicalFacet') {
            Object.assign(facet, {
                filters: this.mapFiltersTree(facet, rawFacet.values, context)
            });
        }
        return facet;
    };
    EmpathyHierarchicalFacetMapper.prototype.mapFiltersTree = function (facet, rawFilters, context) {
        var initFilterProps = { facetId: facet.id, parentId: null };
        return this.mapDeepFilters(rawFilters, initFilterProps, context);
    };
    EmpathyHierarchicalFacetMapper.prototype.mapDeepFilters = function (rawFilters, initFilterProps, context) {
        var _this = this;
        if (rawFilters === void 0) { rawFilters = []; }
        return rawFilters.map(function (rawFilter) {
            var filter = _this.mapFilter(rawFilter, __assign({}, initFilterProps), context);
            filter.children = _this.mapDeepFilters(rawFilter.values, __assign(__assign({}, initFilterProps), { parentId: filter.id }), context);
            return filter;
        });
    };
    EmpathyHierarchicalFacetMapper = __decorate([
        injectable(),
        __param(0, multiInject(DEPENDENCIES.ResponseMappers.hierarchicalFilter)),
        __metadata("design:paramtypes", [Array])
    ], EmpathyHierarchicalFacetMapper);
    return EmpathyHierarchicalFacetMapper;
}());
export { EmpathyHierarchicalFacetMapper };
//# sourceMappingURL=empathy-hierarchical-facet.mapper.js.map